@@ -42,6 +42,8 @@ from quartet_output.transport.sftp import SftpTransportMixin
 from quartet_templates.models import Template
 
 
+
+
 class ContextKeys(Enum):
     """
     Containes Rule Context keys that the steps in this module utilize.
@@ -180,6 +182,7 @@ class OutputParsingStep(EPCISParsingStep):
             'The name value of an EPCIS Output Criteria configuration.'
         )
         self.epc_output_criteria = self.get_output_criteria()
+        self.parser = None
 
     def get_output_criteria(self):
         self.info('Retrieving the Step\'s EPCIS Output Criteria '
@@ -254,6 +257,7 @@ class OutputParsingStep(EPCISParsingStep):
             self.info(str(te))
             parser = SimpleOutputParser(io.BytesIO(data.encode()),
                                         self.epc_output_criteria)
+        self.parser = parser
         return parser
 
     def get_parser_type(self, skip_parsing):
@@ -486,7 +490,7 @@ class AddCommissioningDataStep(rules.Step, FilteredEventStepMixin):
         all_events = self.process_events(all_events)
         self.info('Adding %s Object events to the rule context.',
                   len(all_events))
-        return set(all_events)
+        return all_events
 
     def handle_parent_entries(self, parent_entries: EntryList):
         '''
@@ -890,7 +894,7 @@ class TransportStep(rules.Step, HttpTransportMixin, SftpTransportMixin,
             endpoint.urn
         )
         if parse_result.scheme.lower() in ['http', 'https', 'sftp', 'mailto',
-                                                                    'socket']:
+                                           'socket']:
             return parse_result.scheme
         else:
             raise errors.ProtocolNotSupportedError(_(
